@@ -24,15 +24,16 @@
 #define ABSTRACTXMLGUICONTROLLER_H
 
 // lib
-#include <kasten/abstractcontroller.h>
+#include "abstractcontroller.h"
 
-namespace Kasten {
+namespace Kasten2
+{
 
 class KASTENGUI_EXPORT AbstractXmlGuiController : public AbstractController
 {
-    Q_OBJECT
+  Q_OBJECT
 
-public: // API to be implemented
+  public: // API to be implemented
 //    void plug( KXMLGUIClient* guiClient );
 };
 
